# PAPI IMAPAuth functions
# Copyright (c) 2002-2005, RedIRIS. All Rights Reserved.
#
# You may distribute under the terms of the GNU General Public License,
# as specified in the LICENSE file that was shipped with this distribution.
#
# These functions implement PAPI user authentication using the IMAP protocol.
#

package PAPI::IMAPAuth;
use strict;
use Net::IMAP::Simple;

# This function is intended to be hooked at the authenticationHook in a
# PAPI AuthServer. It uses the connection variables 'username' and
# 'password' to validate them against the POP3 server defined by the
# configuration variable 'IMAPServer'.
# We confirm success by checking that the user has some mailboxes (the
# POP3 version of testing true/false does not work with the
# Net::IMAP::Simple package.
# The user id returned to the AuthServer depends on the configuration
# variable 'IMAPUID', that may take the values:
#    IMAPUSER    => The format is "username", this is the default
#    IMAPSERVER  => The format is "username@IMAPServer"
#
sub IMAPUser {
   my $con = shift;
   my $cfg = shift;
   my $srv = "imap";

   $srv = $$cfg{'IMAPServer'} if (exists $$cfg{'IMAPServer'});
   my $server = Net::IMAP::Simple->new ($srv);
   my $logged_in = $server->login ($$con{'username'}, $$con{'password'});

   if (defined($logged_in)) {
      my $rt = $$con{'username'};
      if (exists $$cfg{'IMAPUID'} && $$cfg{'IMAPUID'} eq "IMAPSERVER") {
         $rt .= "\@$srv";
      }
      $server->quit;
      return $rt;
   }
   else {
      $$con{'PAPIerror'} = "IMAP login failure";
      return undef;
   }
}

1;
